@@ -18,7 +18,7 @@ print.tweights <- function(x, ...) {
   
   
   cat("----------------------------------------------------------------\n")
-  cat("Optimization was successful. The weights have a sampleing\ndistribution with means close to the attemted target:\n")
+  cat("Optimization was successful. The weights have a sampling\ndistribution with means close to the attempted target:\n")
   print(toprint)
   cat("Maximum weight was: ", max(x$weights),"\n")
   if( Nindependent >0 )
